icrn documentation — icrn documentation

# icrn documentation

Add your content using `reStructuredText` syntax. See the reStructuredText documentation for details.

representation.py Module for building ICRNs.

class icrn.representation.FastReaction(*args, **kwargs)

class icrn.representation.ICRNBase

class icrn.representation.IndexSymbol(label, range=None, **kw_args)

class icrn.representation.MassActionReaction(reactants, products, rate_constant, **kwargs)

class icrn.representation.MichaelisMentenReaction(reactants, products, aux=None, name=None, fast=False)

class icrn.representation.RateConstant(label, shape=None, *, offset=0, strides=None, **kw_args)

class icrn.representation.Reaction(reactants, products, aux=None, name=None, fast=False)

exception icrn.representation.RepresentationError

class icrn.representation.Species(label, shape=None, *, offset=0, strides=None, **kw_args)